@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -39,6 +39,8 @@ void GravatarResolvUrlJobTest::shouldHaveDefaultValue()
     QCOMPARE(job.hasGravatar(), false);
     QCOMPARE(job.pixmap().isNull(), true);
     QCOMPARE(job.useDefaultPixmap(), false);
+    QCOMPARE(job.useLibravatar(), false);
+    QCOMPARE(job.fallbackGravatar(), true);
 }
 
 void GravatarResolvUrlJobTest::shouldChangeValue()
@@ -51,6 +53,21 @@ void GravatarResolvUrlJobTest::shouldChangeValue()
     useDefaultPixmap = false;
     job.setUseDefaultPixmap(useDefaultPixmap);
     QCOMPARE(job.useDefaultPixmap(), useDefaultPixmap);
+
+    bool useLibravatar = true;
+    job.setUseLibravatar(useLibravatar);
+    QCOMPARE(job.useLibravatar(), useLibravatar);
+
+    useLibravatar = false;
+    job.setUseLibravatar(useLibravatar);
+    QCOMPARE(job.useLibravatar(), useLibravatar);
+
+    bool fallBackGravatar = false;
+    job.setFallbackGravatar(fallBackGravatar);
+    QCOMPARE(job.fallbackGravatar(), fallBackGravatar);
+    fallBackGravatar = true;
+    job.setFallbackGravatar(fallBackGravatar);
+    QCOMPARE(job.fallbackGravatar(), fallBackGravatar);
 }
 
 void GravatarResolvUrlJobTest::shouldChangeSize()
@@ -81,8 +98,12 @@ void GravatarResolvUrlJobTest::shouldAddSizeInUrl()
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(false);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(true);
+    url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://seccdn.libravatar.org:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldUseDefaultPixmap()
@@ -91,8 +112,8 @@ void GravatarResolvUrlJobTest::shouldUseDefaultPixmap()
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
     job.setUseDefaultPixmap(true);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?s=1024")));
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldUseHttps()
@@ -100,8 +121,12 @@ void GravatarResolvUrlJobTest::shouldUseHttps()
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(QStringLiteral("foo@kde.org"));
     job.setSize(1024);
-    QUrl url = job.generateGravatarUrl();
-    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(false);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
+    job.setUseLibravatar(true);
+    url = job.generateGravatarUrl(job.useLibravatar());
+    QCOMPARE(url, QUrl(QStringLiteral("https://seccdn.libravatar.org/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404&s=1024")));
 }
 
 void GravatarResolvUrlJobTest::shouldNotStart()
@@ -124,10 +149,13 @@ void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("calculedhash");
     QTest::addColumn<QUrl>("output");
-    QTest::newRow("empty") << QString() << QString() << QUrl();
-    QTest::newRow("no domain") << QStringLiteral("foo") << QString() << QUrl();
+    QTest::addColumn<bool>("uselibravatar");
+    QTest::newRow("empty") << QString() << QString() << QUrl() << false;
+    QTest::newRow("no domain") << QStringLiteral("foo") << QString() << QUrl() << false;
     QTest::newRow("validemail") << QStringLiteral("foo@kde.org") << QStringLiteral("89b4e14cf2fc6d426275c019c6dc9de6")
-                                << QUrl(QStringLiteral("https://secure.gravatar.com:443/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404"));
+                                << QUrl(QStringLiteral("https://secure.gravatar.com:/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404")) << false;
+    QTest::newRow("validemaillibravatar") << QStringLiteral("foo@kde.org") << QStringLiteral("89b4e14cf2fc6d426275c019c6dc9de6")
+                                          << QUrl(QStringLiteral("https://seccdn.libravatar.org/avatar/89b4e14cf2fc6d426275c019c6dc9de6?d=404")) << true;
 }
 
 void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl()
@@ -135,9 +163,11 @@ void GravatarResolvUrlJobTest::shouldGenerateGravatarUrl()
     QFETCH(QString, input);
     QFETCH(QString, calculedhash);
     QFETCH(QUrl, output);
+    QFETCH(bool, uselibravatar);
     Gravatar::GravatarResolvUrlJob job;
     job.setEmail(input);
-    QUrl url = job.generateGravatarUrl();
+    job.setUseLibravatar(uselibravatar);
+    QUrl url = job.generateGravatarUrl(job.useLibravatar());
     QCOMPARE(calculedhash, job.calculatedHash().hexString());
     QCOMPARE(url, output);
 }
