@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,9 +20,11 @@
 #include "gravatarconfiguresettingsdialog.h"
 #include "gravatarconfiguresettingswidget.h"
 #include "misc/gravatarcache.h"
-#include "PimCommon/ConfigureImmutableWidgetUtils"
+#include <PimCommon/ConfigureImmutableWidgetUtils>
 
 #include <KLocalizedString>
+#include <KPluralHandlingSpinBox>
+#include <KSeparator>
 #include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -34,9 +36,14 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Configure Gravatar"));
+    setWindowTitle(i18nc("@title:window", "Configure Gravatar"));
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     topLayout->setObjectName(QStringLiteral("toplayout"));
+
+    mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
+    mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
+    topLayout->addWidget(mGravatarConfigureSettings);
+
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -46,9 +53,6 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &GravatarConfigureSettingsDialog::slotRestoreDefault);
     okButton->setDefault(true);
 
-    mGravatarConfigureSettings = new GravatarConfigureSettingsWidget(this);
-    mGravatarConfigureSettings->setObjectName(QStringLiteral("gravatarconfiguresettings"));
-    topLayout->addWidget(mGravatarConfigureSettings);
     topLayout->addWidget(buttonBox);
     load();
 }
