@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,6 +25,7 @@
 class QLabel;
 class QLineEdit;
 class QPushButton;
+class QCheckBox;
 namespace Gravatar {
 class GravatarResolvUrlJob;
 
@@ -47,6 +48,8 @@ private:
     QLabel *mResultLabel = nullptr;
     QLineEdit *mLineEdit = nullptr;
     QPushButton *mGetPixmapButton = nullptr;
+    QCheckBox *mUseLibravatar = nullptr;
+    QCheckBox *mFallbackGravatar = nullptr;
 };
 }
 
